<?php
/**
 * Template for ZF2 module for storing local overrides.
 *
 * PHP version 5
 *
 * Copyright (C) Leipzig University Library 2014.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Module
 * @author   André Lahmann <lahmann@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://github.com/dmj/vf2-proxy
 */
namespace fid_bbi;
use Zend\ModuleManager\ModuleManager,
    Zend\Mvc\MvcEvent;
use Zend\ModuleManager\ModuleEvent;

/**
 * Template for ZF2 module for storing local overrides.
 *
 * @category VuFind
 * @package  Module
 * @author   André Lahmann <lahmann@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://github.com/dmj/vf2-proxy
 */
class Module
{
    /**
     * Get module configuration
     *
     * @return array
     */
    public function getConfig()
    {
        return include __DIR__ . '/config/module.config.php';
    }

    /**
     * Get autoloader configuration
     *
     * @return array
     */
    public function getAutoloaderConfig()
    {
        return [
            'Zend\Loader\StandardAutoloader' => [
                'namespaces' => [
                    __NAMESPACE__ => __DIR__ . '/src/' . __NAMESPACE__,
                ],
            ],
        ];
    }

    /**
     * Initialize the module
     *
     * @param ModuleManager $m Module manager
     *
     * @return void
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function init(ModuleManager $m)
    {
        $m->getEventManager()->attach(ModuleEvent::EVENT_MERGE_CONFIG,[$this,'onMergeConfig']);
    }

    /**
     * Bootstrap the module
     *
     * @param MvcEvent $e Event
     *
     * @return void
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function onBootstrap(MvcEvent $e)
    {
    }

    /**
     * @param MvcEvent $event
     */
    public function onMergeConfig(ModuleEvent $event)
    {
        $configListener = $event->getConfigListener();
        $config         = $configListener->getMergedConfig(false);
        $classes        = array_keys($config['vufind']['recorddriver_tabs']);
        foreach ($classes as $class) {
            $mergedTabOrder = &$config['vufind']['recorddriver_tabs'][$class]['tabs'] ?? [];

            // Change tab order for SolrAI
            if (!empty($mergedTabOrder)) {
                $moduleTabOrder = $this->getConfig()['vufind']['recorddriver_tabs'][$class]['tabs'] ?? [];
                $mergedTabOrder = array_merge($moduleTabOrder, $mergedTabOrder);
            }
        }
        // Pass the changed configuration back to the listener:
        $configListener->setMergedConfig($config);
    }
}
